summaryrefslogtreecommitdiffstats
path: root/kdat/File.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:52:44 -0600
committerSlávek Banko <slavek.banko@axis.cz>2012-06-03 20:26:21 +0200
commit239cc9b83ce0d6dd5216aeb01a82e0d23a0a3595 (patch)
treeb9679d63b6a1004d9983259d41303b5a88a1621a /kdat/File.h
parent1754e4db964431e721e805a923b689b6c92960e4 (diff)
downloadtdeadmin-239cc9b83ce0d6dd5216aeb01a82e0d23a0a3595.tar.gz
tdeadmin-239cc9b83ce0d6dd5216aeb01a82e0d23a0a3595.zip
Remove additional unneeded tq method conversions
(cherry picked from commit 6b7a8ff33a6383be4a9dea3c4225d142aab79b78)
Diffstat (limited to 'kdat/File.h')
-rw-r--r--kdat/File.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kdat/File.h b/kdat/File.h
index 71167f2..75b1d87 100644
--- a/kdat/File.h
+++ b/kdat/File.h
@@ -46,7 +46,7 @@ class File {
} _union;
TQString _name;
File* _parent;
- TQPtrList<File> _tqchildren;
+ TQPtrList<File> _children;
RangeList _ranges;
public:
/**
@@ -80,7 +80,7 @@ public:
File( File* parent, FILE* fptr, int offset );
/**
* Destroy the file entry and all of its tqchildren.
*/
~File();
@@ -95,7 +95,7 @@ public:
/**
* Recursively read the instance for this file entry and all of it's
* tqchildren. This method is used when converting from an older index format.
*
* @param version The version of the old tape index.
*/
@@ -103,7 +103,7 @@ public:
/**
* Write out the file entry to the open file. Entries for each of its
* tqchildren will also be written.
*/
void write( FILE* fptr );
@@ -171,15 +171,15 @@ public:
File* getParent();
/**
* Get the tqchildren of this file entry. A normal file will never have any
* tqchildren. A directory may or may not have tqchildren.
*
* @return A list of the immediate tqchildren of this file entry.
*/
const TQPtrList<File>& getChildren();
/**
* Get the list of ranges of this file and all of its tqchildren.
*
* @return A list of ranges.
*/
@@ -193,7 +193,7 @@ public:
void addChild( File* file );
/**
* Recursively calculate the list of ranges for all of the file's tqchildren.
*/
void calcRanges();
};
@@ -80,7 +80,7 @@ public:
File( File* parent, FILE* fptr, int offset );
/**
- * Destroy the file entry and all of its tqchildren.
+ * Destroy the file entry and all of its children.
*/
~File();
@@ -95,7 +95,7 @@ public:
/**
* Recursively read the instance for this file entry and all of it's
- * tqchildren. This method is used when converting from an older index format.
+ * children. This method is used when converting from an older index format.
*
* @param version The version of the old tape index.
@@ -103,7 +103,7 @@ public:
/**
* Write out the file entry to the open file. Entries for each of its
- * tqchildren will also be written.
+ * children will also be written.
*/
void write( FILE* fptr );
@@ -171,15 +171,15 @@ public:
File* getParent();
/**
- * Get the tqchildren of this file entry. A normal file will never have any
- * tqchildren. A directory may or may not have tqchildren.
+ * Get the children of this file entry. A normal file will never have any
+ * children. A directory may or may not have children.
*
@@ -171,15 +171,15 @@ public:
*
- * @return A list of the immediate tqchildren of this file entry.
+ * @return A list of the immediate children of this file entry.
*/
const TQPtrList<File>& getChildren();
@@ -171,15 +171,15 @@ public:
const TQPtrList<File>& getChildren();
/**
- * Get the list of ranges of this file and all of its tqchildren.
+ * Get the list of ranges of this file and all of its children.
*
* @return A list of ranges.
@@ -193,7 +193,7 @@ public:
void addChild( File* file );
/**
- * Recursively calculate the list of ranges for all of the file's tqchildren.
+ * Recursively calculate the list of ranges for all of the file's children.
*/
void calcRanges();